@@ -33,6 +33,7 @@
 #include <gio/gfileinputstream.h>
 #include <gio/gfileoutputstream.h>
 #include <gio/gmountoperation.h>
+#include <gio/gappinfo.h>
 
 G_BEGIN_DECLS
 
@@ -66,13 +67,25 @@ typedef enum  {
   G_FILE_CREATE_PRIVATE = (1<<0)
 } GFileCreateFlags;
 
+
+/**
+ * GMountMountFlags:
+ * @G_MOUNT_MOUNT_NONE: No flags set.
+ * 
+ * Flags used when mounting a mount.
+ */
+typedef enum  {
+  G_MOUNT_MOUNT_NONE = 0
+} GMountMountFlags;
+
+
 /**
  * GMountUnmountFlags:
  * @G_MOUNT_UNMOUNT_NONE: No flags set.
  * @G_MOUNT_UNMOUNT_FORCE: Unmount even if there are outstanding
  *  file operations on the mount.
  * 
- * Flags used when an operation may create a file.
+ * Flags used when an unmounting a mount.
  */
 typedef enum  {
   G_MOUNT_UNMOUNT_NONE = 0,
@@ -174,7 +187,7 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
  * @get_uri: Gets a URI for the path within a #GFile.
  * @get_parse_name: Gets the parsed name for the #GFile.
  * @get_parent: Gets the parent directory for the #GFile.
- * @contains_file: Checks whether a #GFile contains a specified file.
+ * @prefix_matches: Checks whether a #GFile contains a specified file.
  * @get_relative_path: Gets the path for a #GFile relative to a given path.
  * @resolve_relative_path: Resolves a relative path for a #GFile to an absolute path.
  * @get_child_for_display_name: Gets the child #GFile for a given display name.
@@ -185,8 +198,8 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
  * @query_info_async: Asynchronously gets the #GFileInfo for a #GFile.
  * @query_info_finish: Finishes an asynchronous query info operation.
  * @query_filesystem_info: Gets a #GFileInfo for the file system #GFile is on.
- * @_query_filesystem_info_async: Asynchronously gets a #GFileInfo for the file system #GFile is on.
- * @_query_filesystem_info_finish: Finishes asynchronously getting the file system info.
+ * @query_filesystem_info_async: Asynchronously gets a #GFileInfo for the file system #GFile is on.
+ * @query_filesystem_info_finish: Finishes asynchronously getting the file system info.
  * @find_enclosing_mount: Gets a #GMount for the #GFile.
  * @find_enclosing_mount_async: Asynchronously gets the #GMount for a #GFile.
  * @find_enclosing_mount_finish: Finishes asynchronously getting the volume.
@@ -228,8 +241,8 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
  * @_make_symbolic_link_async: Asynchronously makes a symbolic link
  * @_make_symbolic_link_finish: Finishes making a symbolic link asynchronously.
  * @copy: Copies a file.
- * @_copy_async: Asynchronously copies a file.
- * @_copy_finish: Finishes an asynchronous copy operation.
+ * @copy_async: Asynchronously copies a file.
+ * @copy_finish: Finishes an asynchronous copy operation.
  * @move: Moves a file.
  * @_move_async: Asynchronously moves a file. 
  * @_move_finish: Finishes an asynchronous move operation.
@@ -265,8 +278,8 @@ struct _GFileIface
   char *              (*get_uri)                    (GFile         *file);
   char *              (*get_parse_name)             (GFile         *file);
   GFile *             (*get_parent)                 (GFile         *file);
-  gboolean            (*contains_file)              (GFile         *parent,
-						     GFile         *descendant);
+  gboolean            (*prefix_matches)             (GFile         *prefix,
+						     GFile         *file);
   char *              (*get_relative_path)          (GFile         *parent,
 						     GFile         *descendant);
   GFile *             (*resolve_relative_path)      (GFile        *file,
@@ -311,8 +324,15 @@ struct _GFileIface
 					     const char           *attributes,
 					     GCancellable         *cancellable,
 					     GError              **error);
-  void                (*_query_filesystem_info_async) (void);
-  void                (*_query_filesystem_info_finish) (void);
+  void                (*query_filesystem_info_async) (GFile                *file,
+                                                      const char           *attributes,
+                                                      int                   io_priority,
+                                                      GCancellable         *cancellable,
+                                                      GAsyncReadyCallback   callback,
+                                                      gpointer              user_data);
+  GFileInfo *         (*query_filesystem_info_finish) (GFile                *file,
+                                                       GAsyncResult         *res,
+                                                       GError              **error);
   
   GMount *            (*find_enclosing_mount)(GFile              *file,
 					       GCancellable       *cancellable,
@@ -466,8 +486,18 @@ struct _GFileIface
 					     GFileProgressCallback progress_callback,
 					     gpointer              progress_callback_data,
 					     GError              **error);
-  void                (*_copy_async) (void);
-  void                (*_copy_finish) (void);
+  void                (*copy_async)         (GFile                  *source,
+					     GFile                  *destination,
+					     GFileCopyFlags          flags,
+					     int                     io_priority,
+					     GCancellable           *cancellable,
+					     GFileProgressCallback   progress_callback,
+					     gpointer                progress_callback_data,
+					     GAsyncReadyCallback     callback,
+					     gpointer                user_data);
+  gboolean            (*copy_finish)        (GFile                  *file,
+					     GAsyncResult           *res,
+					     GError                **error);
   
   gboolean            (*move)               (GFile                *source,
 					     GFile                *destination,
@@ -482,6 +512,7 @@ struct _GFileIface
 
 
   void                (*mount_mountable)           (GFile               *file,
+						    GMountMountFlags     flags,
 						    GMountOperation     *mount_operation,
 						    GCancellable         *cancellable,
 						    GAsyncReadyCallback  callback,
@@ -508,6 +539,7 @@ struct _GFileIface
 
 
   void     (*mount_enclosing_volume)        (GFile *location,
+					     GMountMountFlags flags,
 					     GMountOperation *mount_operation,
 					     GCancellable *cancellable,
 					     GAsyncReadyCallback callback,
@@ -548,8 +580,8 @@ GFile *                 g_file_get_child                  (GFile
 GFile *                 g_file_get_child_for_display_name (GFile                      *file,
 							   const char                 *display_name,
 							   GError                    **error);
-gboolean                g_file_contains_file              (GFile                      *parent,
-							   GFile                      *descendant);
+gboolean                g_file_has_prefix                 (GFile                      *file,
+							   GFile                      *prefix);
 char *                  g_file_get_relative_path          (GFile                      *parent,
 							   GFile                      *descendant);
 GFile *                 g_file_resolve_relative_path      (GFile                      *file,
@@ -614,6 +646,9 @@ GFileOutputStream *     g_file_replace_finish             (GFile
 							   GError                    **error);
 gboolean                g_file_query_exists               (GFile                      *file,
 							   GCancellable               *cancellable);
+GFileType               g_file_query_file_type            (GFile                      *file,
+                                                           GFileQueryInfoFlags         flags,
+                                                           GCancellable               *cancellable);
 GFileInfo *             g_file_query_info                 (GFile                      *file,
 							   const char                 *attributes,
 							   GFileQueryInfoFlags         flags,
@@ -633,6 +668,15 @@ GFileInfo *             g_file_query_filesystem_info      (GFile
 							   const char                 *attributes,
 							   GCancellable               *cancellable,
 							   GError                    **error);
+void                    g_file_query_filesystem_info_async (GFile                      *file,
+							   const char                 *attributes,
+							   int                         io_priority,
+							   GCancellable               *cancellable,
+							   GAsyncReadyCallback         callback,
+							   gpointer                    user_data);
+GFileInfo *             g_file_query_filesystem_info_finish (GFile                      *file,
+                                                           GAsyncResult               *res,
+							   GError                    **error);
 GMount *                g_file_find_enclosing_mount       (GFile                      *file,
                                                            GCancellable               *cancellable,
                                                            GError                    **error);
@@ -685,6 +729,18 @@ gboolean                g_file_copy                       (GFile
 							   GFileProgressCallback       progress_callback,
 							   gpointer                    progress_callback_data,
 							   GError                    **error);
+void                    g_file_copy_async                 (GFile                      *source,
+							   GFile                      *destination,
+							   GFileCopyFlags              flags,
+							   int                         io_priority,
+							   GCancellable               *cancellable,
+							   GFileProgressCallback       progress_callback,
+							   gpointer                    progress_callback_data,
+							   GAsyncReadyCallback         callback,
+							   gpointer                    user_data);
+gboolean                g_file_copy_finish                (GFile                      *file,
+							   GAsyncResult               *res,
+							   GError                    **error);
 gboolean                g_file_move                       (GFile                      *source,
 							   GFile                      *destination,
 							   GFileCopyFlags              flags,
@@ -765,6 +821,7 @@ gboolean                g_file_set_attribute_int64        (GFile
 							   GCancellable               *cancellable,
 							   GError                    **error);
 void                    g_file_mount_enclosing_volume     (GFile                      *location,
+							   GMountMountFlags            flags,
 							   GMountOperation            *mount_operation,
 							   GCancellable               *cancellable,
 							   GAsyncReadyCallback         callback,
@@ -773,6 +830,7 @@ gboolean                g_file_mount_enclosing_volume_finish (GFile
 							   GAsyncResult               *result,
 							   GError                    **error);
 void                    g_file_mount_mountable            (GFile                      *file,
+							   GMountMountFlags            flags,
 							   GMountOperation            *mount_operation,
 							   GCancellable               *cancellable,
 							   GAsyncReadyCallback         callback,
@@ -816,6 +874,9 @@ GFileMonitor*           g_file_monitor_file               (GFile
 
 /* Utilities */
 
+GAppInfo *g_file_query_default_handler       (GFile                  *file,
+					      GCancellable           *cancellable,
+					      GError                **error);
 gboolean g_file_load_contents                (GFile                  *file,
 					      GCancellable           *cancellable,
 					      char                  **contents,
