@@ -27,8 +27,9 @@
 #include <string.h>
 
 
-#define PATTERN_FILE_SIZE	0x10000
+#define DEFAULT_TEST_DIR		"testdir_live-g-file"
 
+#define PATTERN_FILE_SIZE	0x10000
 #define TEST_HANDLE_SPECIAL	TRUE
 
 enum StructureExtraFlags
@@ -71,7 +72,7 @@ struct StructureItem
 #define TEST_TARGET_FILE		"target-file"
 
 
-const struct StructureItem sample_struct[] = {
+static const struct StructureItem sample_struct[] = {
 /*	 filename				link	file_type				create_flags		mode | handle_special | extra_flags              */
     {"dir1",				NULL,	G_FILE_TYPE_DIRECTORY,	G_FILE_CREATE_NONE, 0, 0, TEST_DELETE_NORMAL | TEST_DELETE_NON_EMPTY | TEST_REPLACE | TEST_OPEN},
     {"dir1/subdir",			NULL,	G_FILE_TYPE_DIRECTORY,	G_FILE_CREATE_NONE, 0, 0, TEST_COPY	| TEST_COPY_ERROR_RECURSE | TEST_APPEND},
@@ -100,22 +101,13 @@ const struct StructureItem sample_struct[] = {
 	{"lost_symlink",		"nowhere",	G_FILE_TYPE_SYMBOLIC_LINK, G_FILE_CREATE_NONE, 0, 0, TEST_COPY | TEST_DELETE_NORMAL | TEST_OPEN | TEST_INVALID_SYMLINK},
   };
 
-
-
-
 static gboolean write_test;
 static gboolean verbose;
 static gboolean posix_compat;
 
 #define log(msg...) if (verbose)  g_print (msg)
 
-
-
-
-
-
-
-GFile *
+static GFile *
 create_empty_file (GFile * parent, const char *filename,
 		   GFileCreateFlags create_flags)
 {
@@ -124,7 +116,6 @@ create_empty_file (GFile * parent, const char *filename,
   GError *error;
   GFileOutputStream *outs;
 
-
   child = g_file_get_child (parent, filename);
   g_assert (child != NULL);
 
@@ -138,7 +129,7 @@ create_empty_file (GFile * parent, const char *filename,
   return child;
 }
 
-GFile *
+static GFile *
 create_empty_dir (GFile * parent, const char *filename)
 {
   GFile *child;
@@ -154,7 +145,7 @@ create_empty_dir (GFile * parent, const char *filename)
   return child;
 }
 
-GFile *
+static GFile *
 create_symlink (GFile * parent, const char *filename, const char *points_to)
 {
   GFile *child;
@@ -182,7 +173,6 @@ test_create_structure (gconstpointer test_data)
   int i;
   struct StructureItem item;
 
-
   g_assert (test_data != NULL);
   log ("\n  Going to create testing structure in '%s'...\n",
        (char *) test_data);
@@ -194,7 +184,6 @@ test_create_structure (gconstpointer test_data)
   res = g_file_make_directory (root, NULL, NULL);
   /*  don't care about errors here  */
 
-
   /*  create any other items  */
   for (i = 0; i < G_N_ELEMENTS (sample_struct); i++)
     {
@@ -270,11 +259,7 @@ test_create_structure (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
-
-GFile *
+static GFile *
 file_exists (GFile * parent, const char *filename, gboolean * result)
 {
   GFile *child;
@@ -292,7 +277,7 @@ file_exists (GFile * parent, const char *filename, gboolean * result)
   return child;
 }
 
-void
+static void
 test_attributes (struct StructureItem item, GFileInfo * info)
 {
   GFileType ftype;
@@ -381,7 +366,6 @@ test_attributes (struct StructureItem item, GFileInfo * info)
     }
 }
 
-
 static void
 test_initial_structure (gconstpointer test_data)
 {
@@ -406,7 +390,6 @@ test_initial_structure (gconstpointer test_data)
   res = g_file_query_exists (root, NULL);
   g_assert_cmpint (res, ==, TRUE);
 
-
   /*  test the structure  */
   for (i = 0; i < G_N_ELEMENTS (sample_struct); i++)
     {
@@ -433,7 +416,6 @@ test_initial_structure (gconstpointer test_data)
       g_object_unref (child);
     }
 
-
   /*  read and test the pattern file  */
   log ("    Testing pattern file...\n");
   child = file_exists (root, "pattern_file", &res);
@@ -484,12 +466,7 @@ test_initial_structure (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
-
-
-void
+static void
 traverse_recurse_dirs (GFile * parent, GFile * root)
 {
   gboolean res;
@@ -501,7 +478,6 @@ traverse_recurse_dirs (GFile * parent, GFile * root)
   int i;
   gboolean found;
 
-
   g_assert (root != NULL);
 
   error = NULL;
@@ -547,7 +523,6 @@ traverse_recurse_dirs (GFile * parent, GFile * root)
     }
   g_assert (error == NULL);
 
-
   error = NULL;
   res = g_file_enumerator_close (enumerator, NULL, &error);
   g_assert_cmpint (res, ==, TRUE);
@@ -656,12 +631,7 @@ test_enumerate (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
-
-
-void
+static void
 do_copy_move (GFile * root, struct StructureItem item, const char *target_dir,
 	      enum StructureExtraFlags extra_flags)
 {
@@ -695,7 +665,6 @@ do_copy_move (GFile * root, struct StructureItem item, const char *target_dir,
     log ("       res = %d, error code %d = %s\n", res, error->code,
 	 error->message);
 
-
   /*  copying file/directory to itself (".")  */
   if (((item.extra_flags & TEST_NOT_EXISTS) != TEST_NOT_EXISTS) &&
       (extra_flags == TEST_ALREADY_EXISTS))
@@ -758,7 +727,6 @@ test_copy_move (gconstpointer test_data)
   int i;
   struct StructureItem item;
 
-
   log ("\n");
 
   g_assert (test_data != NULL);
@@ -814,10 +782,6 @@ test_copy_move (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
-
 static void
 test_create (gconstpointer test_data)
 {
@@ -828,7 +792,6 @@ test_create (gconstpointer test_data)
   struct StructureItem item;
   GFileOutputStream *os;
 
-
   g_assert (test_data != NULL);
   log ("\n");
 
@@ -837,7 +800,6 @@ test_create (gconstpointer test_data)
   res = g_file_query_exists (root, NULL);
   g_assert_cmpint (res, ==, TRUE);
 
-
   for (i = 0; i < G_N_ELEMENTS (sample_struct); i++)
     {
       item = sample_struct[i];
@@ -866,7 +828,6 @@ test_create (gconstpointer test_data)
 	  if (error)
 	    log ("       error code %d = %s\n", error->code, error->message);
 
-
 	  if (((item.extra_flags & TEST_NOT_EXISTS) == 0) &&
 	      ((item.extra_flags & TEST_CREATE) == TEST_CREATE))
 	    {
@@ -909,9 +870,6 @@ test_create (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
 static void
 test_open (gconstpointer test_data)
 {
@@ -922,7 +880,6 @@ test_open (gconstpointer test_data)
   struct StructureItem item;
   GFileInputStream *input_stream;
 
-
   g_assert (test_data != NULL);
   log ("\n");
 
@@ -931,7 +888,6 @@ test_open (gconstpointer test_data)
   res = g_file_query_exists (root, NULL);
   g_assert_cmpint (res, ==, TRUE);
 
-
   for (i = 0; i < G_N_ELEMENTS (sample_struct); i++)
     {
       item = sample_struct[i];
@@ -984,10 +940,6 @@ test_open (gconstpointer test_data)
   g_object_unref (root);
 }
 
-
-
-
-
 static void
 test_delete (gconstpointer test_data)
 {
@@ -998,7 +950,6 @@ test_delete (gconstpointer test_data)
   int i;
   struct StructureItem item;
 
-
   g_assert (test_data != NULL);
   log ("\n");
 
@@ -1055,7 +1006,6 @@ test_delete (gconstpointer test_data)
 	      g_error_free (error);
 	    }
 
-
 	  g_object_unref (child);
 	}
     }
@@ -1063,15 +1013,79 @@ test_delete (gconstpointer test_data)
 }
 
 
+static void
+cleanup_dir_recurse (GFile *parent, GFile *root)
+{
+  gboolean res;
+  GError *error;
+  GFileEnumerator *enumerator;
+  GFileInfo *info;
+  GFile *descend;
+  char *relative_path;
 
+  g_assert (root != NULL);
 
+  error = NULL;
+  enumerator =
+    g_file_enumerate_children (parent, "*",
+			       G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL,
+			       &error);
+  if (! enumerator)
+	  return;
 
+  error = NULL;
+  info = g_file_enumerator_next_file (enumerator, NULL, &error);
+  while ((info) && (!error))
+    {
+      descend = g_file_get_child (parent, g_file_info_get_name (info));
+      g_assert (descend != NULL);
+      relative_path = g_file_get_relative_path (root, descend);
+      g_assert (relative_path != NULL);
 
+      log ("    deleting '%s'\n", g_file_info_get_display_name (info));
+
+      if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY)
+    	  cleanup_dir_recurse (descend, root);
+      
+      error = NULL;
+      res = g_file_delete (descend, NULL, &error);
+      g_assert_cmpint (res, ==, TRUE);
+
+      g_object_unref (descend);
+      error = NULL;
+      info = g_file_enumerator_next_file (enumerator, NULL, &error);
+    }
+  g_assert (error == NULL);
+
+  error = NULL;
+  res = g_file_enumerator_close (enumerator, NULL, &error);
+  g_assert_cmpint (res, ==, TRUE);
+  g_assert (error == NULL);
+}
+
+static void
+prep_clean_structure (gconstpointer test_data)
+{
+  GFile *root;
+  
+  g_assert (test_data != NULL);
+  log ("\n  Cleaning target testing structure in '%s'...\n",
+       (char *) test_data);
+
+  root = g_file_new_for_commandline_arg ((char *) test_data);
+  g_assert (root != NULL);
+  
+  cleanup_dir_recurse (root, root);
+
+  g_file_delete (root, NULL, NULL);
+  
+  g_object_unref (root);
+}
 
 int
 main (int argc, char *argv[])
 {
-  static gboolean create_struct;
+  static gboolean only_create_struct;
   static char *target_path;
   GError *error;
   GOptionContext *context;
@@ -1079,7 +1093,7 @@ main (int argc, char *argv[])
   static GOptionEntry cmd_entries[] = {
     {"read-write", 'w', 0, G_OPTION_ARG_NONE, &write_test,
      "Perform write tests (incl. structure creation)", NULL},
-    {"create-struct", 'c', 0, G_OPTION_ARG_NONE, &create_struct,
+    {"create-struct", 'c', 0, G_OPTION_ARG_NONE, &only_create_struct,
      "Only create testing structure (no tests)", NULL},
     {"verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose, "Be verbose", NULL},
     {"posix", 'x', 0, G_OPTION_ARG_NONE, &posix_compat,
@@ -1089,7 +1103,7 @@ main (int argc, char *argv[])
 
   verbose = FALSE;
   write_test = FALSE;
-  create_struct = FALSE;
+  only_create_struct = FALSE;
   target_path = NULL;
   posix_compat = FALSE;
 
@@ -1097,6 +1111,20 @@ main (int argc, char *argv[])
   g_type_init ();
   g_test_init (&argc, &argv, NULL);
 
+  /*  no extra parameters specified, assume we're executed from glib test suite  */ 
+  if (argc < 2)
+    {
+	  verbose = TRUE;
+	  write_test = TRUE;
+	  only_create_struct = FALSE;
+	  target_path = DEFAULT_TEST_DIR;
+#ifdef G_PLATFORM_WIN32
+	  posix_compat = FALSE;
+#else
+	  posix_compat = TRUE;
+#endif
+    }
+  
   /*  add trailing args  */
   error = NULL;
   context = g_option_context_new ("target_path");
@@ -1107,54 +1135,67 @@ main (int argc, char *argv[])
       return g_test_run ();
     }
 
-  /*  missing mandatory arg for target dir  */
-  if (argc < 2)
+  /*  remaining arg should is the target path; we don't care of the extra args here  */ 
+  if (argc >= 2)
+    target_path = strdup (argv[1]);
+  
+  if (! target_path) 
     {
+      g_print ("error: target path was not specified\n");
       g_print (g_option_context_get_help (context, TRUE, NULL));
       return g_test_run ();
     }
-  target_path = strdup (argv[1]);
-
-
 
+  
+  /*  Write test - clean target directory first  */
+  /*    this can be also considered as a test - enumerate + delete  */ 
+  if (write_test || only_create_struct)
+    g_test_add_data_func ("/live-g-file/prep_clean_structure", target_path,
+    	  	  prep_clean_structure);
+  
   /*  Write test - create new testing structure  */
-  if (write_test || create_struct)
+  if (write_test || only_create_struct)
     g_test_add_data_func ("/live-g-file/create_structure", target_path,
 			  test_create_structure);
 
   /*  Read test - test the sample structure - expect defined attributes to be there  */
-  if (!create_struct)
+  if (!only_create_struct)
     g_test_add_data_func ("/live-g-file/test_initial_structure", target_path,
 			  test_initial_structure);
 
   /*  Read test - test traverse the structure - no special file should appear  */
-  if (!create_struct)
+  if (!only_create_struct)
     g_test_add_data_func ("/live-g-file/test_traverse_structure", target_path,
 			  test_traverse_structure);
 
   /*  Read test - enumerate  */
-  if (!create_struct)
+  if (!only_create_struct)
     g_test_add_data_func ("/live-g-file/test_enumerate", target_path,
 			  test_enumerate);
 
   /*  Read test - open (g_file_read())  */
-  if (!create_struct)
+  if (!only_create_struct)
     g_test_add_data_func ("/live-g-file/test_open", target_path, test_open);
 
   /*  Write test - create  */
-  if (write_test && (!create_struct))
+  if (write_test && (!only_create_struct))
     g_test_add_data_func ("/live-g-file/test_create", target_path,
 			  test_create);
 
   /*  Write test - copy, move  */
-  if (write_test && (!create_struct))
+  if (write_test && (!only_create_struct))
     g_test_add_data_func ("/live-g-file/test_copy_move", target_path,
 			  test_copy_move);
 
   /*  Write test - delete, trash  */
-  if (write_test && (!create_struct))
+  if (write_test && (!only_create_struct))
     g_test_add_data_func ("/live-g-file/test_delete", target_path,
 			  test_delete);
 
+  if (write_test || only_create_struct)
+    g_test_add_data_func ("/live-g-file/final_clean", target_path,
+    	  	  prep_clean_structure);
+
   return g_test_run ();
+
 }
