@@ -583,7 +583,7 @@ g_spawn_sync (const gchar          *working_directory,
  * If you are writing a GTK+ application, and the program you 
  * are spawning is a graphical application, too, then you may
  * want to use gdk_spawn_on_screen_with_pipes() instead to ensure that 
- * the spawned program opens its windows no the right screen.
+ * the spawned program opens its windows on the right screen.
  * </para></note>
  * 
  * Return value: %TRUE on success, %FALSE if an error was set
@@ -941,7 +941,7 @@ fdwalk (int (*cb)(void *data, int fd), void *data)
   
 #ifdef HAVE_SYS_RESOURCE_H
       
-  if (getrlimit(RLIMIT_NOFILE, &rl) == 0)
+  if (getrlimit(RLIMIT_NOFILE, &rl) == 0 && rl.rlim_max != RLIM_INFINITY)
       open_max = rl.rlim_max;
   else
 #endif
